@@ -3,7 +3,7 @@ import os
 
 import networkx as nx
 
-from . import NetworkXBackend
+from . import NetworkXBackend, DataFrameBackend
 
 try:
     from ._dynamodb import DynamoDBBackend
@@ -12,6 +12,13 @@ try:
 except ImportError:
     _CAN_IMPORT_DYNAMODB = False
 
+try:
+    from ._igraph import IGraphBackend
+
+    _CAN_IMPORT_IGRAPH = True
+except ImportError:
+    _CAN_IMPORT_IGRAPH = False
+
 try:
     from ._sqlbackend import SQLBackend
 
@@ -31,6 +38,15 @@ backend_test_params = [
         ),
     ),
 ]
+backend_test_params = [
+    pytest.param(
+        DataFrameBackend,
+        marks=pytest.mark.skipif(
+            os.environ.get("TEST_DATAFRAMEBACKEND", default="1") != "1",
+            reason="DataFrameBackend skipped because $TEST_DATAFRAMEBACKEND != 1.",
+        ),
+    ),
+]
 
 if _CAN_IMPORT_DYNAMODB:
     backend_test_params.append(
@@ -54,6 +70,17 @@ if _CAN_IMPORT_SQL:
             ),
         ),
     )
+if _CAN_IMPORT_IGRAPH:
+    backend_test_params.append(
+        pytest.param(
+            IGraphBackend,
+            marks=pytest.mark.skipif(
+                os.environ.get("TEST_IGRAPBACKEND", default="1") != "1"
+                or not _CAN_IMPORT_SQL,
+                reason="IGraph Backend skipped because $TEST_IGRAPBACKEND != 1 or igraph is not installed.",
+            ),
+        ),
+    )
 
 if os.environ.get("TEST_NETWORKITBACKEND") == "1":
     from ._networkit import NetworkitBackend
@@ -253,7 +280,7 @@ class TestBackend:
     def test_can_get_edge_metadata(self, backend):
         G = Graph(backend=backend())
         G.nx.add_edge("foo", "bar", baz=True)
-        assert G.nx.edges(data=True) == [("foo", "bar", {"baz": True})]
+        assert list(G.nx.edges(data=True)) == [("foo", "bar", {"baz": True})]
 
     def test_edge_dne_raises(self, backend):
         G = Graph(backend=backend())
